# Changelog

**1.0.5** (2024-11-28)
   * Fixed display bug with two-digit Django versions

**1.0.4** (2024-11-20)
   * Improved docs

**1.0.3** (2024-11-19)
   * Added screenshot to documentation for clarification

**1.0.2** (2024-11-19)
   * Moved `DEFAULT_FILE_STORAGE` removal from Django 3.1 to Django 5.1

**1.0.1** (2024-11-19)
   * Added docs at RTD

**1.0.0** (2024-11-19)
   * Added system checks for all known setting variable removals since Django v1.0
